Struct ZwlrForeignToplevelManagerV1

pub struct ZwlrForeignToplevelManagerV1 { /* private fields */ }
Available on crate feature wayland and Linux only.
list and control opened apps

The purpose of this protocol is to enable the creation of taskbars and docks by providing them with a list of opened applications and letting them request certain actions on them, like maximizing, etc.

After a client binds the zwlr_foreign_toplevel_manager_v1, each opened toplevel window will be sent via the toplevel event

See also the Event enum for this interface.

Implementations



impl ZwlrForeignToplevelManagerV1

pub fn stop(&self)

stop sending events

Indicates the client no longer wishes to receive events for new toplevels. However the compositor may emit further toplevel_created events, until the finished event is emitted.

The client must not send any more requests after this one.